@@ -122,7 +122,7 @@ def context(name: str, injected: object):
     return _inject.context(name, injected)
 
 
-def inject(name: str, injected: object, scope: str = 'process'):
+def inject(*args, **kwargs):
     """Ensures that `injected` is made available under
     `name`.
 
@@ -146,7 +146,19 @@ def inject(name: str, injected: object, scope: str = 'process'):
     sets an attribute `name` on the class with a
     :class:`class_property` instance pointing to `injected`.
     """
-    return _inject(name, injected, scope)
+    kwargs.setdefault('scope', 'process')
+    if len(args) > 1:
+        return _inject(*args, **kwargs)
+
+    # The first argument is a function where each parameter that is annotated
+    # with a string value is considered to refer to an injected dependency.
+    func = args[0]
+    sig = inspect.signature(func)
+    for param in sig.parameters.values():
+        if not isinstance(param.annotation, str):
+            continue
+        func = _inject(param.name, param.annotation)(func)
+    return func
 
 
 class _inject:
